@@ -12,11 +12,11 @@ Text::CSV::Easy - Easy CSV parsing and building
 
 =head1 VERSION
 
-Version 0.51
+Version 0.53
 
 =cut
 
-our $VERSION = '0.51';
+our $VERSION = '0.53';
 
 our @EXPORT_OK = qw(csv_build csv_parse);
 
@@ -51,9 +51,10 @@ This module conforms to RFC 4180 (L<http://tools.ietf.org/html/rfc4180>) for bot
 
  "a,b","a\nb","a""b" => ( 'a,b', "a\nb", 'a"b' )
 
-=item 4. A trailing newline is acceptable.
+=item 4. A trailing newline is acceptable (both LF and CRLF).
 
  abc,def\n           => ( 'abc', 'def' )
+ abc,def\r\n         => ( 'abc', 'def' )
 
 =back
 
